import React from 'react'
import { useInput } from './hooks/input-hook';
import { useState } from "react";
import AuthService from './services/auth.service'
import Button from './Button'
import './LoginForm.css';

export default function LoginForm(props){

    const { value: username, bind: bindUsername, reset: resetUsername } = useInput('')
    const { value: password, bind: bindPassword, reset: resetPassword } = useInput('')
    const [loading, setLoading] = useState(false)
    const [message, setMessage] = useState('')

    const handleLogin = async event => {
        event.preventDefault()
        setLoading(true)

        try {
            await AuthService.login(username, password)
            props.history.push('/')
            window.location.reload()
        }
        catch(error) {
            setMessage('Login failed')
            resetPassword()
            resetUsername()
        }
        setLoading(false)
    }

    return (
        <div className="formContainer">
            <h1>Login</h1>
            <form onSubmit={handleLogin}>
                <div className="login_form-container">
                <label htmlFor='username'>Email</label>
                <input
                    type='text'
                    name='username'
                    className="email"
                    {...bindUsername}
                    required
                    placeholder="Your email"
                />

                <label htmlFor='password'>Password</label>
                <input
                    type='password'
                    name='password'
                    className="password"
                    {...bindPassword}
                    required
                    placeholder="Your password"
                />

                <div className="buttonContainer">
                    <button className='loginButton' disabled={loading}>
                        {loading && (
                            <span className='spinner-border spinner-border-sm'></span>
                        )}
                        <span>Login</span>
                    </button>
                    <Button text="Register" color="green" url="register" />
                </div>

                {message && (
                    <div>
                        <div className='alert alert-danger' role='alert'>
                            {message}
                        </div>
                    </div>
                )}
                </div>
            </form>
        </div>
    )
}
