import React from "react";
import {ReactComponent as DiskuyLogo} from './Logo.svg';
import './Navbar.css';
import { useState } from "react";
import AuthService from './services/auth.service'
import { useInput } from './hooks/input-hook';
import {
    Link, withRouter
  } from "react-router-dom"

const Navbar = (props) => {
    const [loggedIn, setLoggedIn] = useState(AuthService.getCurrentUser() && 1)
    const { value: search, bind: bindSearch, reset: resetSearch } = useInput('')
    
    const handleLogout = () => {
        AuthService.logout()
        setLoggedIn(false)
        window.location.reload()
    }

    const handleSearch = (event) => {
        event.preventDefault()
        props.history.push(`/search/${search}`)
        resetSearch()
    }
    return (
        <nav id = "navbar" className='navbar navbar-expand-lg navbar-light position-sticky fixed-top'>
            <div className="navbar-brand">
                <div className="d-flex align-items-center">
                    <Link to="/"><DiskuyLogo /></Link>
                </div>
            </div>
            <form className='form-inline my-2 my-lg-0 ml-auto' onSubmit={handleSearch}>
                <input className='form-control mr-sm-2' type='search' placholder='search threads' aria-label="Search" {...bindSearch}/>
                <button className='btn my-2 my-sm-0 search' type='submit'>Search</button>
            </form>
            <ul className="navbar-nav ml-auto">
                <li className="nav-item ml-auto">
                    <Link to="/" className="nav-link"><b>Threads</b></Link>
                </li>
                <li className="nav-item ml-auto">
                    <Link to="/topic" className="nav-link"><b>Topics</b></Link>
                </li>
                <li className="nav-item ml-auto">
                    <Link to={`/profile/${AuthService.getCurrentUserId()}`} className="nav-link"><b>Profile</b></Link>
                </li>
                {loggedIn ?  (
                    <li className='nav-item ml-auto' onClick={handleLogout}>
                        <Link to='/login' className='nav-link'><b>Logout</b></Link>
                    </li>
                    ):
                    <li className='nav-item ml-auto'>
                        <Link to='/login' className='nav-link'><b>Login</b></Link>
                    </li>
                }
            </ul>
        </nav>
    );
}

export default withRouter(Navbar);
