import React, { useState, useEffect } from "react";
import './Profile.css';
import Button from '../Button';
import ThreadList from '../Threads/PreviewThread'
import axios from "axios";
import AuthService from '../services/auth.service'
import { API_URL } from '../services/api_link'
import { Link } from "react-router-dom"

function Profile(props) {
    const userId = AuthService.getCurrentUserId();
    const profileId = props.match.params.user;
    const [user, setUser] = useState({
        id:"",
        name:"",
        username: ""
    });
    const [usersThreads, setUsersThreads] = useState([]);

    useEffect(() => {
        async function getUsersThreads(profileId) {
            const allThreads = await axios.get(`${API_URL}/threads`);
            const usersThreads = allThreads.data.data.filter(thread => thread.user_id == profileId);

            const getUser = await axios.get(`${API_URL}/users/${profileId}`);
            const currentUser = getUser.data.data;

            setUsersThreads(usersThreads);
            setUser(currentUser);
        }
        getUsersThreads(profileId);
    }, [userId]);


    return (
        <div>
            <div className="header">
                <h1><b>Profile</b></h1>
            </div>
            <div className="profile_section">
                <div className="userIcon">
                    <i class="far fa-user-circle icon"></i>
                </div>
                <h2><b>{user.username}</b></h2>
            </div>
            <div className="my_threads_section">
                <div className="sub_header_my_threads">
                    <h3><b>Threads Created by {user.username}</b></h3>

                    {userId == profileId && (
                        <Button text="Create Thread" color="orange" url="create/thread" />
                    )}

                </div>
                <div className="list_threads">
                    {usersThreads.map((thread) => (
                        <Link to={`/topic/${thread.topic_name}/${thread.id}`}>
                            <ThreadList
                                header={thread.title}
                                user={thread.username}
                                points={thread.points}
                                time={thread.updated_at}
                                topic={thread.topic_name}
                                user_id={thread.user_id}>
                            </ThreadList>
                        </Link>
                    ))}
                </div>
            </div>
        </div>
    );
}

export default Profile;