import React from 'react'
import AuthService from './services/auth.service'
import { useInput } from './hooks/input-hook';
import { useState } from "react";
import { loggedIn } from './services/loggedInService';
import './RegisterForm.css'

export default function RegisterForm(props){

    const { value: username, bind: bindUsername, reset: resetUsername } = useInput('')
    const { value: password, bind: bindPassword, reset: resetPassword } = useInput('')
    const { value: email, bind: bindEmail, reset: resetEmail } = useInput('')
    const [message, setMessage] =  useState('')

    const handleRegister = async event => {
        event.preventDefault()
        setMessage('')

        try {
            AuthService.register(username, email, password)
            props.history.push('/')
            window.location.reload()
        }
        catch(error){
            setMessage('Register failed')
            resetPassword()
            resetUsername()
            resetEmail()
        }
    }

    return (
        <div className="formContainer">
            <h1>Register</h1>
            <form onSubmit={handleRegister}>
               
                <div className="register_form-container">
                    <label htmlFor='username'>Username</label>
                    <input
                        type='text'
                        name='username'
                        className="username"
                        {...bindUsername}
                        required
                        placeholder="Your username"
                    />

                    <label htmlFor='email'>Email</label>
                    <input
                        type='text'
                        name='email'
                        className="email"
                        {...bindEmail}
                        required
                        placeholder="Your email"
                    />

                    <label htmlFor='password'>Password</label>
                    <input
                        type='password'
                        name='password'
                        className="password"
                        {...bindPassword}
                        required
                        placeholder="password"
                    />
                    <div className="buttonContainer">
                        <button className='registerButton'>Sign Up</button>
                    </div>
                </div>
                

                {message && (
                    <div>
                        <div className='alert alert-danger' role='alert'>
                            {message}
                        </div>
                    </div>
                )}
            </form>
        </div>
    )


}