import axios from "axios";
import React, { useState, useEffect } from "react";
import { useInput } from '../hooks/input-hook';
import './FormCreateThread.css';
import authHeader from '../services/auth-header'
import { API_URL } from '../services/api_link'
import AuthService from '../services/auth.service'

export default function FormCreateThread(props){
    const { value: title, bind: bindTitle, reset: resetTitle } = useInput('')
    const { value: body, bind: bindBody, reset: resetBody } = useInput('')
    const { value: topicId, bind: bindTopicId, reset: resetTopicId } = useInput(0)
    const [listTopic, setlistTopic] = useState([]);
    const userId = AuthService.getCurrentUserId()
    const [message, setMessage] = useState('')

    useEffect(() => {
        async function getListTopic() {
            const allTopic = await (await axios.get(`${API_URL}/topics`)).data.data;
            setlistTopic(allTopic);
        }
        getListTopic();
    }, []);

    const handleSubmit = async (event) => {
        event.preventDefault();
        try {
            await axios.post(`${API_URL}/threads`, {
                thread: {
                    content : body,
                    points : 0,
                    title : title,
                    topic_id : topicId,
                }
            }, 
            {headers: authHeader()})
            const topic = await (await axios.get(`${API_URL}/topics`)).data.data.find(topic => topic.id == topicId)
            const usersThreads = await (await axios.get(`${API_URL}/threads`)).data.data.filter(thread => thread.user_id === userId).sort((a, b) => {
                if (a.id < b.id) return 1
                if (a.id > b.id) return -1
                return 0
            });
            const thisThreads = usersThreads[0];
            props.redirect(`/topic/${thisThreads.topic_name}/${thisThreads.id}`);
        }
        catch(error){
            setMessage("Thread title already exist in the selected topic")
        }
        resetBody(); 
        resetTitle();
        resetTopicId();
    }

    return (
        <div>
            {message && (
                <div>
                    <div className='alert alert-danger' role='alert'>
                        {message}
                    </div>
                </div>
            )}
            <form onSubmit={handleSubmit}>
                <div className="form_container">
                    <label for="title">Title</label>
                    <input type='text' className="title" name="title" placeholder="Your threads title" required="false" {...bindTitle}/>
                    <label>Topic</label>
                    <select className="topic" name="topic" required="false" {...bindTopicId}>
                        <option value=""></option>
                        {listTopic.map((topic) => (
                            <option value={topic.id}>{topic.name}</option>
                        ))}
                    </select>
                    <label for="body">Body</label>
                    <textarea className="body" name="body" placeholder="Tulis" required="false" {...bindBody}/>
                    <div className="buttonContainer">
                        <input type="submit" className="buttonSubmit" value="Create Thread"/>
                    </div>
                </div>
            </form>
            </div>
    )
}
