import axios from "axios";
import React, { useState, useEffect } from "react";
import { useInput } from '../hooks/input-hook';
import './FormEditThread.css';
import authHeader from '../services/auth-header'
import { API_URL } from '../services/api_link'

export default function CreateThreadForm(props){
    const { value: title, setValue: setTitle, bind: bindTitle, reset: resetTitle } = useInput('')
    const { value: body, setValue: setBody, bind: bindBody, reset: resetBody } = useInput('')
    const { value: topicId, setValue: setTopicId, bind: bindTopicId, reset: resetTopicId } = useInput(0)
    const [listTopic, setlistTopic] = useState([]);
    const [point, setPoint] = useState(0);
    const [message, setMessage] = useState('')

    const threadIdParam = props.threadId

    useEffect(() => {
        async function getListTopic() {
            const allTopic = await (await axios.get(`${API_URL}/topics`)).data.data;
            setlistTopic(allTopic);
        }
        getListTopic();
    }, []);

    useEffect(() => {
        async function getDetailThread(threadIdParam) {
            const detailThread = await (await axios.get(`${API_URL}/threads/${threadIdParam}`)).data.data;
            setTitle(detailThread.title);
            setBody(detailThread.content);
            setTopicId(detailThread.topic_id);
            setPoint(detailThread.points)
        }
        getDetailThread(threadIdParam);
    }, [threadIdParam]);

    const handleSubmit = async (event) => {
        event.preventDefault();
        try {
            await axios.put(`${API_URL}/threads/${threadIdParam}`, {
                thread: {
                    content : body,
                    points : point,
                    title : title,
                    topic_id : topicId,
                }
            }, 
            {headers: authHeader()})
            const topic = await (await axios.get(`${API_URL}/topics`)).data.data.find(topic => topic.id == topicId)
            props.redirect(`/topic/${topic.name}/${threadIdParam}`)
        }
        catch(error){
            setMessage("Thread title already exist in the selected topic")
        }
        resetBody(); 
        resetTitle();
        resetTopicId();
    }

    return (
        <div>
            {message && (
                <div>
                    <div className='alert alert-danger' role='alert'>
                        {message}
                    </div>
                </div>
            )}
            <form onSubmit={handleSubmit}>
                <div className="form_container">
                    <label for="title">Title</label>
                    <input type='text' className="title" name="title" placeholder="Your threads title" required="false" {...bindTitle}/>
                    <label>Topic</label>
                    <select className="topic" name="topic" required="false" {...bindTopicId}>
                        <option value=""></option>
                        {listTopic.map((topic) => (
                            <option value={topic.id}>{topic.name}</option>
                        ))}
                    </select>
                    <label for="body">Body</label>
                    <textarea className="body" name="body" placeholder="Tulis" required="false" {...bindBody}/>
                    <div className="buttonContainer">
                        <input type="submit" className="buttonSubmit" value="Edit Thread"/>
                    </div>
                </div>
            </form>
        </div>
    )
}
