import './Post.css';
import axios from 'axios';
import AuthService from '../services/auth.service'
import authHeader from '../services/auth-header'
import React, { useState, useEffect} from 'react'
import { loggedIn } from '../services/loggedInService'
import { translate } from '../helpers/time-util';
import { API_URL } from '../services/api_link'
import Button from '../Button'
import { Link } from 'react-router-dom'

export default function Post(props){
    const checkType = props.type === 'thread' ? 'threads' : 'post'
    const contents = checkType === 'threads' ? props.content.content : props.content.message
    const [points, setPoints] = useState(0)
    const [isLiked, setIsLiked] = useState(false)

    const deletePost = async () => {
        try {
            await axios.delete(`${API_URL}/${checkType}/${props.content.id}`
            ,{headers: authHeader()});
            if (checkType === 'threads') props.redirect()
            else window.location.reload();
        } catch (error) {}
    }

    useEffect(() => {
        const fetch = async () => {
            try {
                const postResponse = await axios.get(`${API_URL}/${checkType}/${props.content.id}`)
                setPoints(postResponse.data.data.points)
                await axios.get(`${API_URL}/${checkType}/checklike/${props.content.id}`, {headers: authHeader()})
                setIsLiked(true)
            }
            catch(error){
                setIsLiked(false)
            }
        }
        fetch()
    }, [checkType, props.content.id])

    const handleLike = async () => {
        try {
            await axios.get(`${API_URL}/${checkType}/checklike/${props.content.id}`, {headers: authHeader()})
            await axios.post(`${API_URL}/${checkType}/dislike/${props.content.id}`, {}, {headers: authHeader()})
            setPoints(points - 1)
            setIsLiked(false)
        }
        catch(error) {
            await axios.post(`${API_URL}/${checkType}/like/${props.content.id}`, {}, {headers: authHeader()})
            setPoints(points + 1)
            setIsLiked(true)
        }
    }

    const time = translate(props.content.inserted_at)

    return (
        <div id="post">
            <div id="postHeader">
                <div id="headerData">
                    <i class="far fa-user-circle"></i>
                    <div className="creator">
                        <p>By  <Link to={`/profile/${props.content.user_id}`}>{props.content.username}</Link> - {time} </p>
                    </div>
                </div>

                <div id="headerButton">
                    <div className="buttonContainer">
                        {props.user_id == AuthService.getCurrentUserId() && (    
                            <Button type="button" text="Edit" color="none-green" url={`thread/edit/${props.content.id}`} />
                        )}
                        {props.content.user_id == AuthService.getCurrentUserId() && (
                            <button type="button" className="deleteButton" onClick={deletePost}>Delete</button>
                        )}
                    </div>
                </div>
                
            </div>
            <div id="postContent">
                {props.type == "thread" && (
                    <h1 id="judul">{props.content.title}</h1>
                )}
                <p id="isi">{contents}</p>
                <div className="likeSection">
                    {loggedIn && (
                        <button className="likeButton" onClick={handleLike}>
                        {isLiked ? 
                            <i class="far fa-thumbs-up active"></i> : 
                            <i class="far fa-thumbs-up inactive"></i>}
                        </button>
                    )}
                    <div className="pointContainer">
                        <div className="point">
                            <p>{points} - likes</p>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    )
}