import React, { useState, useEffect, useCallback } from "react";
import './Thread.css';
import CommentList from './CommentList';
import Post from './Post';
import { useInput } from '../hooks/input-hook';
import axios from 'axios';
import { loggedIn } from '../services/loggedInService'
import authHeader from '../services/auth-header'
import { API_URL } from '../services/api_link'
import AuthService from '../services/auth.service'


export default function Thread(props){
    const currentUserId = AuthService.getCurrentUserId()
    const [isUsersThread, setIsUsersThread] = useState(0);
    const redirect = () => {
        props.history.push(`/topic/${topicParm}`)
    }

    const [thread, setThread] = useState({
        content : "",
        id:"",
        points:0,
        title:"",
        topic_id:"",
        user_id:"",
        updated_at: "",
        inserted_at: "",
        username:""
    });

    const [comment, setComment] = useState([{
        id: "",
        message : "",
        points: 0,
        thread_id: "",
        user_id:"",
        updated_at: "",
        inserted_at: "",
        username:""
    }]);

    const { value: input, bind: bindInput, reset: resetInput } = useInput('');
    const topicParm = props.match.params.topic;
    const threadParm = props.match.params.thread;

    
    const back = () => {
        props.history.goBack();
    }

    const refreshComment = useCallback(() => {
        const fetch = async () => {
            const responseComment = await axios.get(`${API_URL}/post/`);
            const responseCommentData = responseComment.data.data.filter(comments => comments.thread_id == threadParm);
            setComment(responseCommentData);
        }
        fetch();
    }, [threadParm]);

    useEffect(() => {
        const fetch = async () => {
            const responseThread = await axios.get(`${API_URL}/threads/${threadParm}`);
            const responseThreadData = responseThread.data.data;
            setThread(responseThreadData);
            refreshComment();

            if(responseThreadData.user_id == currentUserId) {
                setIsUsersThread(1)
            }
        }
        fetch();
    }, [threadParm, refreshComment, currentUserId]);

    const handleSubmit = async (event) => {
        event.preventDefault();

        try {
            await axios.post(`${API_URL}/post`, {
                post : {
                    message : input,
                    points : 0,
                    thread_id : threadParm,
                    user_id : localStorage.getItem('id')
                }
            },
            {headers: authHeader()})
            refreshComment();
        } catch (error) {}
        resetInput();
    };


    return (
        <div className="threadContainer">
            <div className="back" onClick={back}>
                <h5>Back</h5> 
            </div>
            <div className="thread_section">
                <Post 
                    type="thread"
                    content={thread}
                    redirect={redirect}
                    isUsersThread = {isUsersThread}
                />
            </div>
            
            {loggedIn && (
                <div id="addCommentSection">
                    <h3>Write a Comment</h3>
                    <form onSubmit={handleSubmit}>
                        <textarea className="commentBox" placeholder="Write your comment here" required="false" {...bindInput}/>
                        <button className="submitComment" id="addCommentButton" type="submit">Post Comment</button>
                    </form>
                </div>
            )}
            <h2 className='commentText'>Comments</h2>
            <CommentList comment={comment} thread_id={threadParm} topic_id={topicParm}></CommentList>
        </div>
    )
}