import React, { useEffect, useState } from "react";
import axios from 'axios'
import ThreadList from './Threads/PreviewThread'
import { loggedIn } from './services/loggedInService'
import { API_URL } from './services/api_link'
import { Link } from "react-router-dom"
import './Topic.css'
import Button from './Button'

export default function Topic(props){
    const [thread, setThread] = useState([])
    const topicParam = props.match.params.topic

    useEffect(() => {
        const fetch = async () => {
            try {
                const responseThreads = await axios.get(`${API_URL}/threads/`)
                const responseTopics = await axios.get(`${API_URL}/topics`)
           
                const topic = responseTopics.data.data.find(topic => topic.name === topicParam).id
                const threads = responseThreads.data.data.filter(thread => thread.topic_id === topic)
                const sortedThreads = threads.sort((a, b) => {
                if (a.id < b.id) return 1
                if (a.id > b.id) return -1
                return 0
                })
                setThread(sortedThreads)
            } catch(error){}
        }
        fetch()   
    }, [topicParam])

    return (
        <div>
        <div className="header">
            <h1><b>Topic: {topicParam}</b></h1>
            {loggedIn && (
            <Button text="Create Thread" color="orange" url="create/thread" />
        )}
        </div>
        <div className="list_threads_section">
            {thread.map((value) => (
                <Link to={`/topic/${topicParam}/${value.id}` } style={{ textDecoration: 'none' }}>
                    <ThreadList
                        header={value.title}
                        user={value.username}
                        points={value.points}
                        time={value.inserted_at}
                        topic={value.topic_name}>
                    </ThreadList>
                </Link>
            ))}
        </div>
        </div>
    )
}